Palley and Soll (2019) recruited participants through ClearVoice Research and Amazon Mechanical Turk to estimate the probability that one team or the other would win various games in the 2014, 2015, and 2016 NCAA Division I Men<U+2019>s Basketball Tournaments. The responses for the Round of 64 games and Round of 16 games are treated separately because the Round of 64 games happen at the start of the tournament and often involve heavily mismatched teams (e.g., a 1 seed versus a 16 seed) while Round of 16 games typically involve more evenly matched teams, with implied betting market probabilities closer to 50%.
E_NCAA_R64E_NCAA_R16
P_NCAA_R64
P_NCAA_R16
THETA_NCAA_R64
THETA_NCAA_R16
ID_NCAA_R64
ID_NCAA_R16
E_NCAA_R64is a list of the judges' estimates of the probability that the given team wins in Round of 64. Specifically, the \(j\)th element is a vector of the judges' estimated probability in the \(j\)th game.
E_NCAA_R16is a list of the judges' estimates of the probability that the given team wins in Round of 16. Specifically, the \(j\)th element is a vector of the judges' estimated probability in the \(j\)th game.
P_NCAA_R64is a list of the judges' predictions of other judges' average probability that the given team wins in Round of 64. Specifically, the \(j\)th element is a vector of the judges' predictions of the other judges' average probabilities in the \(j\)th game.
P_NCAA_R16is a list of the judges' predictions of other judges' average probability that the given team wins in Round of 16. Specifically, the \(j\)th element is a vector of the judges' predictions of the other judges' average probabilities in the \(j\)th game.
THETA_NCAA_R64is a vector of the actual outcomes of the games in the Round of 64. Specifically, the \(j\)th element is the actual outcome of \(j\)th game in Round of 64.
THETA_NCAA_R16is a vector of the actual outcomes of the games in the Round of 16. Specifically, the \(j\)th element is the actual outcome of \(j\)th game in Round of 16.
ID_NCAA_R64is a list of the judges' identification numbers in the judgment tasks associated with the Round of 64 games. Specifically, the \(j\)th element is a vector of identification numbers of judges' who participated in estimating the probability of a given team winning the \(j\)th game of Round of 64. These values make it possible to track a judge across judgment tasks.
ID_NCAA_R16is a list of the judges' identification numbers in the judgment tasks associated with the Round of 16 games. Specifically, the \(j\)th element is a vector of identification numbers of judges' who participated in estimating the probability of a given team winning the \(j\)th game of Round of 16. These values make it possible to track a judge across judgment tasks.
The elements of each list correspond to the same game. Specifically, the \(j\)th elements of
THETA_NCAA_R16, E_NCAA_R16, P_NCAA_R16, and ID_NCAA_R16
represent the true outcome, estimates, the predictions of others, and identification
numbers associated with the \(j\)th game in the Round of 16.