Palley and Soll (2019) recruited volunteers passing through the student union to estimate the total price of 10 different bundles of nonperishable grocery items. Examples of items include a bottle of 190 Lil Critters Gummy Vites Sour Complete multivitamins ($10.93), a 5-oz. can of Wild Planet wild albacore tuna in extra virgin olive oil ($4.19), and an 11 oz. bag of Stauffer's Animal Crackers ($1.00).
E_GROCERIESP_GROCERIES
THETA_GROCERIES
ID_GROCERIES
E_GROCERIESis a list of the judges' estimates of the prices in each of the 10 bundles of groceries. Specifically, the \(j\)th element is a vector of the judges' estimates of the price of the \(j\)th bundle.
P_GROCERIESis a list of the judges' predictions of others. Specifically, the \(j\)th element is a vector of the judges' predictions of other judges' average estimate of the price of the \(j\)th bundle.
THETA_GROCERIESis a vector of the prices of the 10 bundles of groceries. Specifically, the \(j\)th element is the actual price of the \(j\)th bundle.
ID_GROCERIESis a list of the judges' identification numbers in the judgment tasks. Specifically, the \(j\)th element is a vector of identification numbers of judges' who participated in estimating the price of the \(j\)th bundle. These values make it possible to track a judge across judgment tasks.
The elements of each list correspond to the same judgment task. Specifically, the \(j\)th elements of
THETA_GROCERIES, E_GROCERIES, P_GROCERIES, and ID_GROCERIES
represent the true price, estimates, the predictions of others, and identification
numbers associated with the \(j\)th bundle.